@@ -1,4 +1,4 @@
-# Copyright (c) 2014 cPanel, Inc.
+# Copyright (c) 2016 cPanel, Inc.
 # All rights reserved.
 # http://cpanel.net/
 #
@@ -95,6 +95,8 @@ sub open {
     return $fh;
 }
 
+=back
+
 =head1 MOVING MESSAGES
 
 =over
@@ -140,11 +142,32 @@ sub parse_flags {
     return $ret;
 }
 
+=head1 REMOVING MESSAGES
+
+=over
+
+=item C<$message-E<gt>remove()>
+
+Unlink the current message.
+This method has the same return value as L<perlfunc/unlink>.
+B<Note:> if removal succeeds, the object is no longer valid and should be disposed of.
+
+Do not use this to soft-delete messages. For that, set the C<T> flag instead.
+
+=back
+
+=cut
+
+sub remove {
+    my ( $self ) = @_;
+    return unlink $self->{'file'};
+}
+
 =head1 SETTING MESSAGE FLAGS
 
 =over
 
-=item C<$message-E<gt>mark(I<$flags>)>
+=item C<$message-E<gt>mark(I<$flags>, I<$queue>)>
 
 Set any of the following message status flags on the current message.  More
 than one flag may be specified in a single call, in any order.
@@ -177,21 +200,54 @@ Mark the message as "Flagged".
 
 =back
 
+You can also specify the queue to which the message will be moved:
+
+=over
+
+=item * Missing or undefined
+
+Move the message to C<cur>.
+
+=item * C<tmp>
+
+Move the message to C<tmp>.
+
+=item * C<new>
+
+Move the message to C<new>.
+
+=item * C<cur>
+
+Move the message to C<cur>.
+
+=item * C<keepq>
+
+Keep the message in the same queue, do not move it.
+
 =back
 
 =cut
 
 sub mark {
-    my ( $self, $flags ) = @_;
+    my ( $self, $flags, $dir ) = @_;
     $flags = parse_flags($flags);
 
+    if ( defined $dir ) {
+        die('Queue may only be "keepq", "tmp", "new" or "cur"') unless $dir =~ /^(?:keepq|tmp|new|cur)$/;
+        $dir = $self->{'dir'} if $dir eq 'keepq';
+    }
+    else {
+        $dir = 'cur';
+    }
+
     my $mailbox_dir = $self->{'maildir'}->mailbox_dir( $self->{'mailbox'} );
-    my $new_file    = "$mailbox_dir/cur/$self->{'name'}:2,$flags";
+    my $new_file    = "$mailbox_dir/$dir/$self->{'name'}:2,$flags";
 
     unless ( rename( $self->{'file'}, $new_file ) ) {
         die("Unable to rename() $self->{'file'} to $new_file: $!");
     }
 
+    $self->{'dir'}   = $dir;
     $self->{'file'}  = $new_file;
     $self->{'flags'} = $flags;
 
@@ -286,9 +342,9 @@ __END__
 
 =head1 AUTHOR
 
-Xan Tronix <xan@cpan.org>
+Alexandra Hrefna Hilmisdóttir <xan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014, cPanel, Inc.  Distributed under the terms of the MIT
+Copyright (c) 2016, cPanel, Inc.  Distributed under the terms of the MIT
 license.  See the LICENSE file for further details.
